@@ -82,12 +82,6 @@ int parseRangeFormat(const std::string& s, std::string* chr, unsigned int* begin
     i++;
   }
   i ++; //skip ':'
-  // "chr1"
-  if (i >= s.size() || s[i] == '\0') {
-    *begin = 0;
-    *end = 1 <<29; //tabix use this constant
-    return 0;
-  }
   
   std::string t;
   while (i < s.size()){
@@ -109,13 +103,15 @@ int parseRangeFormat(const std::string& s, std::string* chr, unsigned int* begin
   }
 
   i ++ ; // skip '-'
-  int e = 1<<29;     // that's the constant used in tabix
-  if (s[i] == '\0'){ //format like: 1:100-
-    *end = 1<<29;  // that's the constant used in tabix
-  } else{
-    if (!str2int(s.c_str() + i, &e) || e < 0 || b > e) return false;
+  if (s[i] == '\0') {  // format like: 1:100-
+    *end = 1 << 29;    // that's the constant used in tabix
+  } else {
+    int e;
+    if (!str2int(s.c_str() + i, &e) || e < 0 || b > e) {
+      return -1;
+    }
+    *end = e;
   }
-  *end = e;
 
   // REprintf( "parse result: %s %d %d\n", chr->c_str(), *begin, *end);
   return 0;
