@@ -1,5 +1,5 @@
 #define _POSIX_C_SOURCE 200112L /* Rsamtools: c99 fileno */
-#define _SVID_SOURCE            /* Rsamtools: c99 strdup */
+#define _DEFAULT_SOURCE            /* Rsamtools: c99 strdup */
 
 /* The MIT License
 
